'use strict';

import React from "react";
import Reflux from "reflux";
import JsonLdUtils from "jsonld-utils";

import Actions from "../../actions/Actions";
import Constants from "../../constants/Constants";
import I18nWrapper from "../../i18n/I18nWrapper";
import injectIntl from "../../utils/injectIntl";
import MessageWrapper from "../misc/MessageWrapper";
import OptionsStore from "../../stores/OptionsStore";
import Reports from "./Reports";
import ReportStore from "../../stores/ReportStore";
import Routes from "../../utils/Routes";
import Routing from "../../utils/Routing";
import RoutingRules from "../../utils/RoutingRules";

class ReportsController extends Reflux.Component {
    constructor(props) {
        super(props);
        this.i18n = props.i18n;
        this.state = {};
        this.stores = [OptionsStore, ReportStore];
        this.storeKeys = ['reports', Constants.OPTIONS.OCCURRENCE_TYPE];
    }

    componentWillMount() {
        super.componentWillMount();
        RoutingRules.execute(Routes.reports.name);
        Actions.loadAllReports();
        Actions.loadOptions(Constants.OPTIONS.OCCURRENCE_TYPE);
    }

    onCreateReport = () => {
        Routing.transitionTo(Routes.createReport);
    };

    onEditReport = (report) => {
        Routing.transitionTo(Routes.editReport, {
            params: {reportId: report.id},
            handlers: {onCancel: Routes.reports}
        });
    };

    onDeleteReport = (report) => {
        Actions.deleteReport(report, () => this.props.showSuccessMessage(this.i18n('reports.delete.success-msg')));
    };

    render() {
        const actions = {
            createReport: this.onCreateReport,
            editReport: this.onEditReport,
            deleteReport: this.onDeleteReport
        };
        return <Reports actions={actions} reports={this.state.reports}
                        types={JsonLdUtils.processTypeaheadOptions(this.state[Constants.OPTIONS.OCCURRENCE_TYPE], this.props.intl)}/>;
    }
}

export default injectIntl(I18nWrapper(MessageWrapper(ReportsController)));
