'use strict';

import React from "react";
import PropTypes from "prop-types";
import Reflux from "reflux";

import Actions from "../../../actions/Actions";
import Constants from "../../../constants/Constants";
import I18nWrapper from "../../../i18n/I18nWrapper";
import injectIntl from "../../../utils/injectIntl";
import OptionsStore from "../../../stores/OptionsStore";
import Select from "../../Select";
import Utils from "../../../utils/Utils";

class OccurrenceSeverity extends Reflux.Component {
    constructor(props) {
        super(props);
        this.i18n = props.i18n;
        this.state = {};
        this.store = OptionsStore;
        this.storeKey = [Constants.OPTIONS.SEVERITY];
    }

    componentDidMount() {
        Actions.loadOptions(Constants.OPTIONS.SEVERITY);
    }

    _processOptions() {
        const options = this.state[Constants.OPTIONS.SEVERITY];
        return options ? options.map(o => {
            return {
                label: Utils.constantToString(o, true),
                value: o
            };
        }) : [];
    }

    render() {
        const occurrence = this.props.occurrence,
            options = this._processOptions();
        return <Select name='severity' options={options} label={this.i18n('occurrence.severity') + '*'}
                       title={this.i18n('occurrence.severity-tooltip')} addDefault
                       value={occurrence.severity} onChange={this.props.onChange}/>;
    }
}

OccurrenceSeverity.propTypes = {
    onChange: PropTypes.func.isRequired,
    occurrence: PropTypes.object.isRequired
};

export default injectIntl(I18nWrapper(OccurrenceSeverity));
